import pygtk
pygtk.require('2.0')
import gtk, gobject, pango
import os
import logging
import locale
from gettext import gettext as _

from mamamedia_modules import BorderFrame, BORDER_ALL_BUT_BOTTOM, BORDER_ALL_BUT_TOP, BORDER_ALL, BORDER_RIGHT, BORDER_HORIZONTAL
from mamamedia_modules import BasicReaderWidget as NotebookReaderWidget
#from mamamedia_ui import NotebookReaderWidget, BorderFrame

from sugar.activity.activity import Activity, ActivityToolbox, get_bundle_path
COLOR_OUTSIDE_BG = "#027F01"
COLOR_BG = "#68CD05"
COLOR_FRAME_OUTER = "#FFFF00"
COLOR_FRAME_GAME = "#FF0099"

COLOR_FG_BUTTONS = (
    (gtk.STATE_NORMAL,"#FFFFFF"),
    (gtk.STATE_ACTIVE,"#FFFFFF"),
    (gtk.STATE_PRELIGHT,"#FFFFFF"),
    (gtk.STATE_SELECTED,"#FFFFFF"),
    (gtk.STATE_INSENSITIVE,"#FFFFFF"),
    )
COLOR_BG_BUTTONS = (
    (gtk.STATE_NORMAL,"#027F01"),
    (gtk.STATE_ACTIVE,"#014D01"),
    (gtk.STATE_PRELIGHT,"#016D01"),
    (gtk.STATE_SELECTED,"#027F01"),
    (gtk.STATE_INSENSITIVE,"#027F01"),
    )


def prepare_btn(btn, w=-1, h=-1):
    for state, color in COLOR_BG_BUTTONS:
        btn.modify_bg(state, gtk.gdk.color_parse(color))
    c = btn.get_child()
    if c is not None:
        for state, color in COLOR_FG_BUTTONS:
            c.modify_fg(state, gtk.gdk.color_parse(color))
    else:
        for state, color in COLOR_FG_BUTTONS:
            btn.modify_fg(state, gtk.gdk.color_parse(color))
    if w>0 or h>0:
        btn.set_size_request(w, h)
    c.modify_font(pango.FontDescription("normal 8"))
    return btn

class LearningCenter (Activity):
    def __init__(self, handle):
        Activity.__init__(self, handle)
        self._canvas = BorderFrame(size=25, border_color=COLOR_OUTSIDE_BG)
        self._canvas.show()
        self.prepare_activity(_("Learning Center"))
        
#        # The containers we will use
        outer_box = gtk.EventBox()#BorderFrame(border_color=COLOR_FRAME_OUTER)
        outer_box.modify_bg(gtk.STATE_NORMAL,gtk.gdk.color_parse(COLOR_BG))
        outer_box.show()
        inner_box = gtk.VBox(False)
        inner_box.show()
        img_box = gtk.HBox(False)
        img_box.show()
        #img_box.modify_bg(gtk.STATE_NORMAL,gtk.gdk.color_parse(COLOR_BG))
        img_logo = gtk.Image()
        img_logo.set_from_file("icons/logo.png")
        img_logo.show()
        img_box.pack_start(img_logo, False)
        spacer = BorderFrame(border=BORDER_ALL_BUT_BOTTOM, border_color=COLOR_FRAME_OUTER, bg_color=COLOR_BG)
        spacer.show()
        img_box.pack_start(spacer, True)
        inner_box.pack_start(img_box, False)
        

        tabs_outer_box = gtk.HBox(False)
        tabs_outer_box.show()
        tabs_box = BorderFrame(border=BORDER_ALL, border_color=COLOR_FRAME_OUTER, bg_color=COLOR_BG)
        tabs_box.show()
        tabs = gtk.HBox(False)
        tabs.show()
        tabs_box.add(tabs)
        tabs_outer_box.pack_start(tabs_box, True)
        spacer = BorderFrame(border=BORDER_RIGHT, border_color=COLOR_FRAME_OUTER, bg_color=COLOR_BG)
        spacer.show()
        spacer.set_size_request(20,-1)
        tabs_outer_box.pack_start(spacer, False)
        inner_box.pack_start(tabs_outer_box, False)
        

        body_box = BorderFrame(border=BORDER_ALL_BUT_TOP, border_color=COLOR_FRAME_OUTER, bg_color=COLOR_BG)
        body_box.show()
        
        canvas_box = BorderFrame(border=BORDER_ALL_BUT_TOP, size=15, border_color=COLOR_BG)
        canvas_box.show()
        self.viewport = NotebookReaderWidget('tabs')
        self.viewport.show()
        body = BorderFrame(border_color=COLOR_FRAME_GAME)
        body.show()
        body.add(self.viewport)
        canvas_box.add(body)
        body_box.add(canvas_box)
        inner_box.pack_start(body_box, True)
        outer_box.add(inner_box)

        self._canvas.add(outer_box)
        self.set_canvas(self._canvas)

        self.setup_tabs(tabs)


    def prepare_activity (self, title):
        os.chdir(get_bundle_path())
        logging.debug('Starting %s activity... %s' % (title, str(get_bundle_path())))
        self.set_title(title)
        toolbox = ActivityToolbox(self)
        self.set_toolbox(toolbox)
        toolbox.show()
        if hasattr(self, '_jobject'):
            self._jobject.metadata['title'] = title
        title_widget = toolbox._activity_toolbar.title
        title_widget.set_size_request(title_widget.get_layout().get_pixel_size()[0] + 20, -1)

    def setup_tabs (self, container):
        container.foreach(container.remove)
        for name, path in self.viewport.get_lessons():
            wrapper = BorderFrame(border=BORDER_RIGHT, border_color=COLOR_FRAME_OUTER, bg_color=COLOR_OUTSIDE_BG)
            inner_wrapper = BorderFrame(border=BORDER_HORIZONTAL, size=10, border_color=COLOR_OUTSIDE_BG, bg_color=COLOR_OUTSIDE_BG)
            wrapper.show()
            inner_wrapper.show()
            a = prepare_btn(gtk.Button(name.upper()))
            a.show()
            wrapper.add(inner_wrapper)
            inner_wrapper.add(a)
            container.pack_start(wrapper, False)
            a.connect('clicked', self.load_lesson, path)
        spacer = gtk.Label()
        spacer.show()
        container.pack_start(spacer, True)
        
    def load_lesson (self, btn, path):
        self.viewport.load_lesson(path)
